#include "TDirectory.h"
#include "TStyle.h"
#include "TFile.h"

#include "StatsDisplay.h"

//rootFileTest_lib_EXPORT StatsDisplay *gStatsDisplay = new StatsDisplay();
StatsDisplay *gStatsDisplay = new StatsDisplay();

StatsDisplay::StatsDisplay()
{
	fFileSize = new TMultiGraph();
	fEventSize = new TMultiGraph();
	fWriteRealSpeed = new TMultiGraph();
	fReadRealSpeed = new TMultiGraph();
	fWriteCPUSpeed = new TMultiGraph();
	fReadCPUSpeed = new TMultiGraph();

	fFileSize->SetTitle("File Size;# Events;Megabytes (MB)");
	fFileSize->SetMinimum(0);
	fEventSize->SetTitle("Event Size;# Events;Kilobytes (KB)");
	fEventSize->SetMinimum(0);
	fWriteRealSpeed->SetTitle("Write Speed (Real Time);# Events;Events / Real Time (s)");
	fWriteRealSpeed->SetMinimum(0);
	fReadRealSpeed->SetTitle("Read Speed (Real Time);# Events;Events / Real Time (s)");
	fReadRealSpeed->SetMinimum(0);
	fWriteCPUSpeed->SetTitle("Write Speed (CPU Time);# Events;Events / CPU Time (s)");
	fWriteCPUSpeed->SetMinimum(0);
	fReadCPUSpeed->SetTitle("Read Speed (CPU Time);# Events;Events / CPU Time (s)");
	fReadCPUSpeed->SetMinimum(0);

	fStyle = new TStyle("Default", "StatsDisplay Style");
	fStyle->SetFrameBorderMode(0);
	fStyle->SetPadBorderMode(0);
	fStyle->SetTitleYOffset(1.5);
	fStyle->SetPadGridX(1);
	fStyle->SetPadGridY(1);
	fStyle->SetMarkerStyle(5);
	fStyle->SetLineWidth(2);
	fStyle->cd();

	fGFileSize = new TGraph();
	fGEventSize = new TGraph();
	fGWriteRealSpeed = new TGraph();
	fGReadRealSpeed = new TGraph();
	fGWriteCPUSpeed = new TGraph();
	fGReadCPUSpeed = new TGraph();

	fPadWidth = 350;
	fPadHeight = 350;

	fCanvas = new TCanvas("fCanvas", "StatsDisplay", fPadWidth*3, fPadHeight*2);
	fCanvas->Divide(3, 2);
}

void StatsDisplay::AddAllGraphs(const char *name, Color_t color = kBlack)
{
	// Set graph name for legend
	fGFileSize->SetName(name);
	fGFileSize->SetLineColor(color);
	fGFileSize->SetMarkerColor(color);
	fGFileSize->SetFillStyle(0);

	fGEventSize->SetName(name);
	fGEventSize->SetLineColor(color);
	fGEventSize->SetMarkerColor(color);
	fGEventSize->SetFillStyle(0);

	fGWriteRealSpeed->SetName(name);
	fGWriteRealSpeed->SetLineColor(color);
	fGWriteRealSpeed->SetMarkerColor(color);
    fGWriteRealSpeed->SetFillStyle(0);

	fGReadRealSpeed->SetName(name);
	fGReadRealSpeed->SetLineColor(color);
	fGReadRealSpeed->SetMarkerColor(color);
    fGReadRealSpeed->SetFillStyle(0);

	fGWriteCPUSpeed->SetName(name);
	fGWriteCPUSpeed->SetLineColor(color);
	fGWriteCPUSpeed->SetMarkerColor(color);
    fGWriteCPUSpeed->SetFillStyle(0);

	fGReadCPUSpeed->SetName(name);
	fGReadCPUSpeed->SetLineColor(color);
	fGReadCPUSpeed->SetMarkerColor(color);
    fGReadCPUSpeed->SetFillStyle(0);

	fFileSize->Add(fGFileSize);
	fEventSize->Add(fGEventSize);
	fWriteRealSpeed->Add(fGWriteRealSpeed);
	fReadRealSpeed->Add(fGReadRealSpeed);
	fWriteCPUSpeed->Add(fGWriteCPUSpeed);
	fReadCPUSpeed->Add(fGReadCPUSpeed);
}

void StatsDisplay::ResetGraphs()
{
	fGFileSize = new TGraph();
	fGEventSize = new TGraph();
	fGWriteCPUSpeed = new TGraph();
	fGReadCPUSpeed = new TGraph();
	fGWriteRealSpeed = new TGraph();
	fGReadRealSpeed = new TGraph();
}

void StatsDisplay::Draw()
{
	fStyle->cd();
	fCanvas->UseCurrentStyle();
	fCanvas->cd(1);
	fFileSize->Draw("APL");
	fCanvas->GetPad(1)->BuildLegend(0.12, 0.67, 0.5, 0.88);
	fCanvas->cd(2);
	fEventSize->Draw("APL");
	fCanvas->cd(3);
	fWriteRealSpeed->Draw("APL");
	fCanvas->cd(4);
	fReadRealSpeed->Draw("APL");
	fCanvas->cd(5);
	fWriteCPUSpeed->Draw("APL");
	fCanvas->cd(6);
	fReadCPUSpeed->Draw("APL");
}

void StatsDisplay::Save(const char *fileName)
{
	TDirectory *currDir = gDirectory;
	TFile *outF = new TFile(fileName, "RECREATE");
	outF->cd();
	fCanvas->Write();
	fCanvas->SaveAs("canvas.png");
	currDir->cd();
}
